Changelog
=========

0.6.6 (2019-09-23)
------------------

- pyramid: fixup tweenview init

0.6.6 (2019-09-23)
------------------

- pyramid: register trace in a tweenview

0.6.5 (2019-09-17)
------------------

- advertise version in pyramid module

0.6.4 (2019-09-18)
------------------

- do not throw exception when trying to format to thrift

0.6.3 (2019-09-18)
------------------

- ensure zipkin does not raise when trace id is larger than expected

0.6.2 (2019-09-17)
------------------

- do not throw warning on configuration mistakes

0.6.1 (2019-09-17)
------------------

- fixup python2 support

0.6.0 (2019-09-17)
------------------

- refactor pyramid plugin
- fix reporter

0.5 (2019-09-10)
----------------

- Use thriftpy2

0.4 (2015-08-21)
----------------

-  Flask bindings
-  xmlrpclib client bindings
-  Filtered parameters in sqlalchemy binding
-  Implement exponential backoff on connection


0.3 (2015-02-16)
----------------

-  Make the service name configurable for pyramid application


0.2 (2015-02-16)
----------------

-  Keep @trace usable when zipkin is not configured


0.1 (2015-02-16)
----------------

-  Initial version
